==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/GitHubWebHookCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GitHubWebHookCauseBuilder extends io.fabric8.openshift.api.model.GitHubWebHookCauseFluentImpl<io.fabric8.openshift.api.model.GitHubWebHookCauseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GitHubWebHookCause,io.fabric8.openshift.api.model.GitHubWebHookCauseBuilder>{
  public GitHubWebHookCauseBuilder() {
    this(false);
  }
  public GitHubWebHookCauseBuilder(java.lang.Boolean validationEnabled) {
    this(new GitHubWebHookCause(), validationEnabled);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent) {
    this(fluent, false);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GitHubWebHookCause(), validationEnabled);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GitHubWebHookCause instance) {
    this(fluent, instance, false);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GitHubWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRevision(instance.getRevision()); 
    fluent.withSecret(instance.getSecret()); 
    this.validationEnabled = validationEnabled; 
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCause instance) {
    this(instance,false);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRevision(instance.getRevision()); 
    this.withSecret(instance.getSecret()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GitHubWebHookCause build() {
    GitHubWebHookCause buildable = new GitHubWebHookCause(fluent.getRevision(),fluent.getSecret());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitHubWebHookCauseBuilder that = (GitHubWebHookCauseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/GitHubWebHookCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GitHubWebHookCauseBuilder extends io.fabric8.openshift.api.model.GitHubWebHookCauseFluentImpl<io.fabric8.openshift.api.model.GitHubWebHookCauseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GitHubWebHookCause,io.fabric8.openshift.api.model.GitHubWebHookCauseBuilder>{
  public GitHubWebHookCauseBuilder() {
    this(false);
  }
  public GitHubWebHookCauseBuilder(java.lang.Boolean validationEnabled) {
    this(new GitHubWebHookCause(), validationEnabled);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent) {
    this(fluent, false);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GitHubWebHookCause(), validationEnabled);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GitHubWebHookCause instance) {
    this(fluent, instance, false);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GitHubWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRevision(instance.getRevision()); 
    fluent.withSecret(instance.getSecret()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCause instance) {
    this(instance,false);
  }
  public GitHubWebHookCauseBuilder(io.fabric8.openshift.api.model.GitHubWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRevision(instance.getRevision()); 
    this.withSecret(instance.getSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GitHubWebHookCause build() {
    GitHubWebHookCause buildable = new GitHubWebHookCause(fluent.getRevision(),fluent.getSecret());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitHubWebHookCauseBuilder that = (GitHubWebHookCauseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
